@@ -1,5 +1,4 @@
-# Created: 17.05.2019
-# Copyright (c) 2019, Manfred Moitzi
+# Copyright (c) 2019-2021, Manfred Moitzi
 # License: MIT License
 from typing import TYPE_CHECKING, Iterable, List, Mapping, Set
 import json
@@ -26,7 +25,39 @@ if TYPE_CHECKING:
     from ezdxf.eztypes import DXFEntity, Linetype, DXFTag, BlockLayout
     from ezdxf.entities.polygon import BasePolygon
 
-__all__ = ["entities_to_code", "block_to_code", "table_entries_to_code"]
+__all__ = [
+    "entities_to_code",
+    "block_to_code",
+    "table_entries_to_code",
+    "black",
+]
+
+
+def black(code: str, line_length=88, fast: bool = True) -> str:
+    """Returns the source `code` as a single string formatted by `Black`_
+
+    Requires the installed `Black`_ formatter::
+
+        pip3 install black
+
+    Args:
+        code: source code
+        line_length: max. source code line length
+        fast: ``True`` for fast mode, ``False`` to check that the reformatted
+            code is valid
+
+    Raises:
+        ImportError: Black is not available
+
+    .. _black: https://pypi.org/project/black/
+
+    """
+
+    import black
+
+    mode = black.FileMode()
+    mode.line_length = line_length
+    return black.format_file_contents(code, fast=fast, mode=mode)
 
 
 def entities_to_code(
@@ -118,6 +149,18 @@ class Code:
         lead_str = " " * indent
         return "\n".join(lead_str + line for line in self.code)
 
+    def black_code_str(self, line_length=88) -> str:
+        """Returns the source code as a single string formatted by `Black`_
+
+        Args:
+            line_length: max. source code line length
+
+        Raises:
+            ImportError: Black is not available
+
+        """
+        return black(self.code_str(), line_length)
+
     def __str__(self) -> str:
         """Returns the source code as a single string."""
 
@@ -747,6 +790,8 @@ class _SourceCodeGenerator:
                     if edge.type == EdgeType.LINE:
                         add_line(f"ep.add_line({edge.start}, {str(edge.end)})")
                     elif edge.type == EdgeType.ARC:
+                        # Start- and end angles are always stored in ccw
+                        # orientation:
                         add_line("ep.add_arc(")
                         add_line(arg.format("center", str(edge.center)))
                         add_line(arg.format("radius", edge.radius))
@@ -755,6 +800,8 @@ class _SourceCodeGenerator:
                         add_line(arg.format("ccw", edge.ccw))
                         add_line(")")
                     elif edge.type == EdgeType.ELLIPSE:
+                        # Start- and end params are always stored in ccw
+                        # orientation:
                         add_line("ep.add_ellipse(")
                         add_line(arg.format("center", str(edge.center)))
                         add_line(arg.format("major_axis", str(edge.major_axis)))
